multistore-cf-workers 0.2.0

Cloudflare Workers runtime adapters for the multistore S3 proxy gateway
docs.rs failed to build multistore-cf-workers-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

multistore-cf-workers

Cloudflare Workers runtime adapters for the multistore S3 proxy gateway.

Overview

Provides everything needed to run the multistore proxy on Cloudflare Workers: a ProxyBackend implementation using the Fetch API, zero-copy request/response streaming via native ReadableStream, an object_store HTTP connector, and response conversion helpers.

This crate only compiles for wasm32-unknown-unknown.

Feature Flags

  • azure — Azure Blob Storage backend support
  • gcp — Google Cloud Storage backend support